@@ -818,4 +818,87 @@ class Crudifier(_Crudifier):
         return prepare_for_crude_dispatch(func, **vars(self))
 
 
+from i2 import name_of_obj, Sig
+from dol import chain_get
+
+# Note: Could use function objects themselves as keys instead of (or along with) function names. Pros/cons?
+
+# alt arg names:
+# def crudify_based_on_names(func, *, input_store_for_arg=(), output_store_for_func_name=()):  pass
+
+
+def _remove_non_valued_items(d: dict):
+    return {k: v for k, v in d.items() if v is not None}
+
+
+def _keys_to_search(func):
+    """Function defining what forms of keys will be searched in the arg_input_stores
+    when using crudify_based_on_names on a function.
+    Note that since chain_get will be used on this, it's the first key found that will be used,
+    making, for example, a ``(func, arg_name)`` specification have precedence over an `arg_name` specification"""
+    func_name = name_of_obj(func)
+    for arg_name in Sig(func).names:
+        yield (
+            arg_name,
+            (
+                (func, arg_name),
+                (func_name, arg_name),
+                f'{func_name}.{arg_name}',
+                arg_name,
+            ),
+        )
+
+
+def crudify_based_on_names(
+    func, *, arg_input_stores=(), func_output_stores=(), crudifier=Crudifier
+):
+    """
+    Crudify a function based on general
+
+    :param func:
+    :param arg_input_stores:
+    :param func_output_stores:
+    :param crudifier:
+    :return:
+
+    >>> from functools import partial
+    >>> def foo(x, y):
+    ...     return x + y
+    >>> def bar(a, x):
+    ...     return a * x
+    >>> general_crudifier = partial(
+    ...     crudify_based_on_names,
+    ...     arg_input_stores={'x': 'x_store'},
+    ...     crudifier=partial(prepare_for_crude_dispatch, mall={'x_store': {'stored_two': 2, 'stored_four': 4}})
+    ... )
+    >>>
+    >>> foo, bar = map(general_crudifier, [foo, bar])
+    >>>
+    >>> foo('stored_two', 10)
+    12
+    >>> bar(4, 'stored_four')
+    16
+
+    """
+    arg_input_stores = dict(arg_input_stores)
+    func_output_stores = dict(func_output_stores)
+    func_name = name_of_obj(func)
+    param_to_mall_map = (
+        _remove_non_valued_items(
+            {
+                arg_name: chain_get(arg_input_stores, keys)
+                for arg_name, keys in _keys_to_search(func)
+            }
+        )
+        or None
+    )
+    output_store = chain_get(func_output_stores, (func, func_name), default=None)
+    if param_to_mall_map or output_store:
+        return crudifier(
+            func, param_to_mall_map=param_to_mall_map, output_store=output_store
+        )
+    else:
+        return func
+
+
 # ---------------------------------------------------------------------------------------
